<?php 
/**
 * CLink Licensable Functions
 *
 * CLink licensable functions
 *
 * @package CLink
 * @subpackage Content Manager
 */
// Direct Access Not Allowed
defined( 'ABSPATH' ) or die( 'No script kiddies please!' );
/**
 * CLink Find Image by URL
 * 
 * @param string $image_url  Image URL
 * 
 * @return boolean if found true else false
 */
function wpclink_find_image_id_by_url($image_url = ''){
	
	$upload_dir = wp_get_upload_dir();
	
		$postslist = get_posts( array(
			'posts_per_page' => -1,
			'order'          => 'ASC',
			'orderby'        => 'title',
			'post_type'		 => array('attachment'),
			'post_status' => array('publish', 'pending', 'draft', 'auto-draft', 'future', 'private', 'inherit', 'trash') 
	) );
	if ( $postslist ) {
		foreach ( $postslist as $post ) :
		
		$image_data = wp_get_attachment_metadata($post->ID);
		
		$image_guid = get_the_guid($post->ID);
		$image_scale = wp_get_attachment_url($post->ID);
		
		
		$image_url = strtok((string)$image_url, '?');
		
		if(!empty($image_url)){
			if(strpos($image_guid, $image_url) !== false){
				return $post->ID;
			}
		}
		
		if(!empty($image_url)){
			if(strpos($image_scale, $image_url) !== false){
				return $post->ID;
			}
		}
		
		
		
			
		/* Set up an empty array for the links. */
	$links = array();
	/* Get the intermediate image sizes and add the full size to the array. */
	$sizes = get_intermediate_image_sizes($post->ID);
	$sizes[] = 'full';
	/* Loop through each of the image sizes. */
	foreach ( $sizes as $size ) {
		/* Get the image source, width, height, and whether it's intermediate. */
		$image = wp_get_attachment_image_src( $post->ID , $size );
		/* Add the link to the array if there's an image and if $is_intermediate (4th array value) is true or full size. */
		if ( !empty( $image ) && ( true == $image[3] || 'full' == $size ) )
			$links[] = "$image[0]";
		
		
		if(!empty($image_url)){
		if(strpos((string)$image[0], (string)$image_url) !== false){
				return $post->ID;
			} else{
			}
		}
		
		
	}
		
	
	
	$found_image_id = apply_filters( 'wpclink_image_find_by_src', 0, $post->ID, $image_url);
	if($found_image_id > 0 ){
		return $found_image_id;
	}
		
	
		//print_r($image_urls);
		
		endforeach;
		
			
		
	}
}
/**
 * CLink Get Image Attributes
 * 
 * @param integer $attachment  attachment id
 * 
 * @return array attributes
 */
function wpclink_get_image_attributes($attachment_id = 0){
	
	// Data
	$clink_array = array();
	
	// CLink ID
	if($contentID = get_post_meta( $attachment_id, 'wpclink_creation_ID', true )){
		$clink_array['creation_ID'] = $contentID;
		$clink_array['creation_ID_url'] = WPCLINK_ID_URL.'/#objects/'.$contentID;		
	}
	
	
	
	// Reuse
	$registered_list_attachment = wpclink_get_option('referent_attachments');
	if(!is_array($registered_list_attachment)) $registered_list_attachment = array();
	
	if(in_array($attachment_id, $registered_list_attachment)){
		$clink_array['reuse'] = 1;
		$clink_array['reuse_domain'] = 'same_domain';
		
		if($sync_origin = get_post_meta( $attachment_id, 'wpclink_referent_post_uri', true )){
			if(empty($sync_origin)){
				
				$media_license_url = get_bloginfo( 'url' );
				$media_license_url = add_query_arg( 'clink_media_license', '', $media_license_url );
				$media_license_url = add_query_arg( 'id', $attachment_id, $media_license_url );
				$reuse_GUID = add_query_arg( 'clink', 'offer', $media_license_url );
				
				$clink_array['reuse_url'] = urlencode($reuse_GUID);
				
			}else{
				$clink_array['reuse_url'] = urlencode($sync_origin);
			}
		}else{
			
				$media_license_url = get_bloginfo( 'url' );
				$media_license_url = add_query_arg( 'clink_media_license', '', $media_license_url );
				$media_license_url = add_query_arg( 'id', $attachment_id, $media_license_url );
				$reuse_GUID = add_query_arg( 'clink', 'offer', $media_license_url );
			
				$clink_array['reuse_url'] = urlencode($reuse_GUID);
		}
		
		
		
		$clink_array['license_terms'] = 'https://licenses.clink.id/personal/0-9i';
		
	}else if($sync_origin = get_post_meta( $attachment_id, 'wpclink_referent_post_uri', true )){
		if(!empty($sync_origin)){
			
			// Custom URL
			$custom_url = get_post_meta( $attachment_id, 'wpclink_custom_url', true );
			
			$clink_array['reuse'] = 1;
			$custom_url_reuse = add_query_arg( 'clink', 'offer', $custom_url );
			$clink_array['reuse_url'] = urlencode($custom_url_reuse);
			$clink_array['orgin_url'] = urlencode($custom_url);
			
			
			
		}
	}else{
		
	}
	
	$license_type = get_post_meta( $attachment_id, 'wpclink_license_selected_type', true );
	if($license_type == 'custom'){
		$custom_license_value = get_post_meta( $attachment_id, 'wpclink_custom_url', true );
		$clink_array['custom-license'] = $custom_license_value;
	}
	
	$clink_array['use_mouse_over'] = 1;
	
	return $clink_array;
	
}
/**
 * CLink Licensable DOM HTML
 * 
 * @param string $html Content
 * 
 * @return string Content
 */
function wpclink_licensble_images_start($html,$post_id = 0){
	
	// Enable error catch
	//libxml_use_internal_errors(TRUE);
	
	// UTF-8 Doc Document
	$html = '<meta http-equiv="Content-Type" content="text/html; charset=UTF-8" />'.$html;
	
	$doc = new DOMDocument('1.0', 'UTF-8');
	$doc->substituteEntities = TRUE;
    // If faild to load HTML
	if(@$doc->loadHTML($html) === false){
		return $html;
	}
	
	// Catch LibXML errors
	//$errors = libxml_get_errors();
	
	$image_linked_array = array();
	
	
	//Create new wrapper div
	$new_div = $doc->createElement('div');
	$new_div->setAttribute('class','clink-imagebox');
	
	
	
	
		
    $images= $doc->getElementsByTagName('img');
    foreach ($images as $image) {
	
		if($image->hasAttribute('src')){
			
			
			//Clone our created div
    		$new_div_clone = $new_div->cloneNode();
			
			
			// Source Attribute
			$src_attr = $image->getAttribute('src');
			
			
			
			// Remove Query
			//$src_attr = strtok((string)$src_attr, '?');
			
			//var_dump($src_attr);
			
			// Attachment ID
			$attach_id = wpclink_find_image_id_by_url((string)$src_attr);
			
			// Remove Query
			$src_attr = strtok((string)$src_attr, '?');
			
			
			//var_dump($attach_id);
			
			// is Attachment
			if($attach_id > 0){
				
				
				$clink_attr = wpclink_get_image_attributes($attach_id);
				$show_button = get_post_meta( $attach_id, 'wpclink_license_button', true );
				
				if(isset($clink_attr['creation_ID'])){
					if(!empty($clink_attr['creation_ID'])){
						
						
						$image_linked_array[$src_attr]['creation_ID'] = $clink_attr['creation_ID'];
						
						$media_license_url = get_bloginfo( 'url' );
						$media_license_url = add_query_arg( 'clink_media_license', '', $media_license_url );
						$media_license_url = add_query_arg( 'id', $attach_id, $media_license_url );
					
						$image_linked_array[$src_attr]['orgin_url'] = urlencode($media_license_url);
                      
                      
						if($image->hasAttribute('data-creation-id')){
							$image->setAttribute('src', $clink_attr['creation_ID']);
						}else{
							
							$doc_attr = $doc->createAttribute('data-creation-id');
							$doc_attr->value = wpclink_strip_prefix_clink_ID($clink_attr['creation_ID']);
						
							// Append it to the document itself 
							$image->appendChild($doc_attr); 
						}
						
						
											
					if(!empty($clink_attr['orgin_url'])){		
						if($image->hasAttribute('data-referent-post-url')){
										$image->setAttribute('data-referent-post-url', $clink_attr['orgin_url']);
									}else{
										$doc_attr = $doc->createAttribute('data-referent-post-url');
										$doc_attr->value = $clink_attr['orgin_url'];
										// Append it to the document itself 
										$image->appendChild($doc_attr); 
									}
					}
				
			
                      
                      
					  $archive_link = wpclink_get_last_archive($attach_id);  
						
                      if(!empty($archive_link)){
                        
                        $image_linked_array[$src_attr]['archive_link'] = $archive_link;
                        
                      }
                      
                      
						if(!empty($clink_attr['creation_ID_url'])){
							
							$image_linked_array[$src_attr]['creation_ID_url'] = $clink_attr['creation_ID_url'];
							if($image->hasAttribute('data-creation-id-url')){
								$image->setAttribute('src', $clink_attr['creation_ID_url']);
							}else{
								$doc_attr = $doc->createAttribute('data-creation-id-url');
								$doc_attr->value = $clink_attr['creation_ID_url'];
								// Append it to the document itself 
								$image->appendChild($doc_attr); 
							}
							
						}
						
						
						
					if(isset($clink_attr['reuse'])){
							if(!empty($clink_attr['reuse'])){
								
								$image_linked_array[$src_attr]['reuse'] = $clink_attr['reuse'];
								
								$image_linked_array[$src_attr]['reuse_url'] = $clink_attr['reuse_url'];
								
								if($image->hasAttribute('data-reuse')){
									$image->setAttribute('data-reuse', $clink_attr['reuse']);
								}else{
									$doc_attr = $doc->createAttribute('data-reuse');
									$doc_attr->value = $clink_attr['reuse'];
									// Append it to the document itself 
									$image->appendChild($doc_attr); 
								}
								
								if($image->hasAttribute('data-reuse-url')){
									$image->setAttribute('data-reuse-url', $clink_attr['reuse_url']);
								}else{
									$doc_attr = $doc->createAttribute('data-reuse-url');
									$doc_attr->value = $clink_attr['reuse_url'];
									// Append it to the document itself 
									$image->appendChild($doc_attr); 
								}
							}
						}
						
					
					if(!empty($show_button) and $show_button != 'na'){
						
						
						if(isset($clink_attr['custom-license'])){
							if(!empty($clink_attr['custom-license'])){
								
								// Custom License
								$image_linked_array[$src_attr]['custom-license'] = $clink_attr['custom-license'];
								// Button Label
								$image_linked_array[$src_attr]['button-label'] = $show_button;
								
								// Custom License			
								if($image->hasAttribute('data-custom-license')){
									$image->setAttribute('data-custom-license', $clink_attr['custom-license']);
								}else{
									$doc_attr = $doc->createAttribute('data-custom-license');
									$doc_attr->value = $clink_attr['custom-license'];
									// Append it to the document itself 
									$image->appendChild($doc_attr); 
								}
								
								// Button Label
								if($image->hasAttribute('data-button-label')){
									$image->setAttribute('data-button-label', $show_button);
								}else{
									$doc_attr = $doc->createAttribute('data-button-label');
									$doc_attr->value = $show_button;
									// Append it to the document itself 
									$image->appendChild($doc_attr); 
								}
								
								
							}
						}
					}else{
						$image_linked_array[$src_attr]['custom-license'] = '';
						// Button Label
						$image_linked_array[$src_attr]['button-label'] = 'na';
					}
						
						if(isset($clink_attr['use_mouse_over'])){
							if(!empty($clink_attr['use_mouse_over'])){	
								
								$image_linked_array[$src_attr]['use_mouse_over'] = $clink_attr['use_mouse_over'];
								
								if($image->hasAttribute('data-use-mouse-over')){
									$image->setAttribute('data-use-mouse-over', $clink_attr['use_mouse_over']);
								}else{
									$doc_attr = $doc->createAttribute('data-use-mouse-over');
									$doc_attr->value = $clink_attr['use_mouse_over'];
									// Append it to the document itself 
									$image->appendChild($doc_attr); 
								}
							}
						}
					
						
					}
				}
				
				
			
			}else{
				
				$class = $image->getAttribute('class');
				preg_match('/wp-image-[0-9]+/', $class, $content);
				
				$content = str_replace('wp-image-','',$content);
				
				if(is_numeric($content[0])){

				$attach_id =$content[0];
				
				$clink_attr = wpclink_get_image_attributes($attach_id);
				
				if(isset($clink_attr['creation_ID'])){
					if(!empty($clink_attr['creation_ID'])){
						
						
						$image_linked_array[$src_attr]['creation_ID'] = $clink_attr['creation_ID'];
						
						$media_license_url = get_bloginfo( 'url' );
						$media_license_url = add_query_arg( 'clink_media_license', '', $media_license_url );
						$media_license_url = add_query_arg( 'id', $attach_id, $media_license_url );
					
						$image_linked_array[$src_attr]['orgin_url'] = urlencode($media_license_url);
                      
                      
						if($image->hasAttribute('data-creation-id')){
							$image->setAttribute('src', $clink_attr['creation_ID']);
						}else{
							
							$doc_attr = $doc->createAttribute('data-creation-id');
							$doc_attr->value = wpclink_strip_prefix_clink_ID($clink_attr['creation_ID']);
						
							// Append it to the document itself 
							$image->appendChild($doc_attr); 
						}
						
						
						
                      
                      
					  $archive_link = wpclink_get_last_archive($attach_id);  
						
                      if(!empty($archive_link)){
                        
                        $image_linked_array[$src_attr]['archive_link'] = $archive_link;
                        
                      }
                      
                      
						if(!empty($clink_attr['creation_ID_url'])){
							
							$image_linked_array[$src_attr]['creation_ID_url'] = $clink_attr['creation_ID_url'];
							if($image->hasAttribute('data-creation-id-url')){
								$image->setAttribute('src', $clink_attr['creation_ID_url']);
							}else{
								$doc_attr = $doc->createAttribute('data-creation-id-url');
								$doc_attr->value = $clink_attr['creation_ID_url'];
								// Append it to the document itself 
								$image->appendChild($doc_attr); 
							}
							
						}
						
						
						
					if(isset($clink_attr['reuse'])){
							if(!empty($clink_attr['reuse'])){
								
								$image_linked_array[$src_attr]['reuse'] = $clink_attr['reuse'];
								
								$image_linked_array[$src_attr]['reuse_url'] = $clink_attr['reuse_url'];
								
								if($image->hasAttribute('data-reuse')){
									$image->setAttribute('data-reuse', $clink_attr['reuse']);
								}else{
									$doc_attr = $doc->createAttribute('data-reuse');
									$doc_attr->value = $clink_attr['reuse'];
									// Append it to the document itself 
									$image->appendChild($doc_attr); 
								}
								
								if($image->hasAttribute('data-reuse-url')){
									$image->setAttribute('data-reuse-url', $clink_attr['reuse_url']);
								}else{
									$doc_attr = $doc->createAttribute('data-reuse-url');
									$doc_attr->value = $clink_attr['reuse_url'];
									// Append it to the document itself 
									$image->appendChild($doc_attr); 
								}
							}
						}
						
						if($show_button == 1){
							if(isset($clink_attr['custom-license'])){
								if(!empty($clink_attr['custom-license'])){

									$image_linked_array[$src_attr]['custom-license'] = $clink_attr['custom-license'];


									if($image->hasAttribute('data-custom-license')){
										$image->setAttribute('data-custom-license', $clink_attr['custom-license']);
									}else{
										$doc_attr = $doc->createAttribute('data-custom-license');
										$doc_attr->value = $clink_attr['custom-license'];
										// Append it to the document itself 
										$image->appendChild($doc_attr); 
									}

									}
							}
						}else{
							$image_linked_array[$src_attr]['custom-license'] = '';
						}
						
						
						if(isset($clink_attr['use_mouse_over'])){
							if(!empty($clink_attr['use_mouse_over'])){	
								
								$image_linked_array[$src_attr]['use_mouse_over'] = $clink_attr['use_mouse_over'];
								
								if($image->hasAttribute('data-use-mouse-over')){
									$image->setAttribute('data-use-mouse-over', $clink_attr['use_mouse_over']);
								}else{
									$doc_attr = $doc->createAttribute('data-use-mouse-over');
									$doc_attr->value = $clink_attr['use_mouse_over'];
									// Append it to the document itself 
									$image->appendChild($doc_attr); 
								}
							}
						}
					
						
					}
				}
				
				
			

				}
			}
			
		if(wpclink_is_amp_active()){
			
		$clink_attr = wpclink_get_image_attributes($attach_id);		
			
		// If Registered	
		if(isset($clink_attr['creation_ID'])){
		if(!empty($clink_attr['creation_ID'])){

		// Unique ID
		$uniq_id = uniqid();

		$image->parentNode->replaceChild($new_div_clone,$image);

		//Append this image to wrapper div
		$new_div_clone->appendChild($image);

		/* Image Panel */
		$image_panel = $doc->createElement("div");
		$image_panel->setAttribute('class','clink-imagepanel');
		$added_image_panel = $new_div_clone->appendChild($image_panel);


		/* Reuse URL */
		if(isset($clink_attr['reuse'])){
			if(!empty($clink_attr['reuse'])){

				$reuse_url = $clink_attr['reuse_url'];

				$show_button = get_post_meta( $attach_id, 'wpclink_license_button', true );
				if(!empty($show_button) and $show_button != 'na'){

				}else{
					$show_button = 'Get a License';
				}

				$get_license = $doc->createElement("a",$show_button);
				$get_license->setAttribute('class','cl-resuse');
				$get_license->setAttribute('target','_blank');
				$get_license->setAttribute('href',urldecode($reuse_url));
				$added_image_panel->appendChild($get_license);	

			}
		}


		// Clink more links
		$clink_more_links = $doc->createElement("div");
		$clink_more_links->setAttribute('class','clink-more-links');
		$added_more_links = $added_image_panel->appendChild($clink_more_links);

		// Span
		$span = $doc->createElement("span");	

		$span_attr = $doc->createAttribute('on');
		$span_attr->value = 'tap:clbtn-'.$uniq_id.'.show';
		$span_done = $span->appendChild($span_attr);
		$adde_span = $added_more_links->appendChild($span);	



		// Clink ul links
		$clink_ul_links = $doc->createElement("div");
		$clink_ul_links->setAttribute('class','clink-ul-links cl-amp-btn');
		$clink_ul_links->setAttribute('id','clbtn-'.$uniq_id);
			
		// By Default Hidden
		$attr_hidden = $doc->createAttribute('hidden');
		$clink_ul_links_done = $clink_ul_links->appendChild($attr_hidden);
		$clink_ul_links_added = $added_more_links->appendChild($clink_ul_links);


		$li_creation = $doc->createElement("li");
		$li_a = $doc->createElement("a",'Provenance and rights');
		$li_a->setAttribute('class','cl-clinkid');
		$li_a->setAttribute('target','_blank');
		$li_a->setAttribute('href',$clink_attr['creation_ID_url']);

		$li_creation_added = $clink_ul_links_added->appendChild($li_creation);
		$li_creation_done = $li_creation_added->appendChild($li_a);
				
		if(isset($clink_attr['orgin_url']) and !empty($clink_attr['orgin_url'])){

			// Li Referent
			$li_referent = $doc->createElement("li");
			$li_referent->setAttribute('class','archive_link');

			// A Referent
			$li_referent_a = $doc->createElement("a",'Referent (Origin)');
			$li_referent_a->setAttribute('target','_blank');
			$li_referent_a->setAttribute('href',urldecode($clink_attr['orgin_url']));

			// SVG
			$svg_referent = $doc->createElement("svg");
			$svg_referent->setAttribute('xmlns','http://www.w3.org/2000/svg');	
			$svg_referent->setAttribute('viewBox','0 0 24 24');	
			$svg_referent->setAttribute('class','ico_link');	


			$li_referent_a_added = $li_referent_a->appendChild($svg_referent);	
			$li_added = $clink_ul_links_added->appendChild($li_referent);
			$a_added = $li_added->appendChild($li_referent_a);
			$svg_added = $a_added->appendChild($svg_referent);

			$svg_referent_path = $doc->createElement("path");
			$svg_referent_path->setAttribute('d','M15.6 7.2H14v1.5h1.6c2 0 3.7 1.7 3.7 3.7s-1.7 3.7-3.7 3.7H14v1.5h1.6c2.8 0 5.2-2.3 5.2-5.2 0-2.9-2.3-5.2-5.2-5.2zM4.7 12.4c0-2 1.7-3.7 3.7-3.7H10V7.2H8.4c-2.9 0-5.2 2.3-5.2 5.2 0 2.9 2.3 5.2 5.2 5.2H10v-1.5H8.4c-2 0-3.7-1.7-3.7-3.7zm4.6.9h5.3v-1.5H9.3v1.5z');

			$svg_path_added = $svg_added->appendChild($svg_referent_path);


			}
		}
		}

		}
	   
	}
		
	
	
			
		
		
	
	}
	
	if(!empty($image_linked_array)){
		update_post_meta($post_id,'wpclink_media_attributes',$image_linked_array);
	}
	
	return $doc->saveHTML();
	
	
}
/**
 * CLink Linked Licensable DOM HTML
 * 
 * @param string $html Content
 * 
 * @return string Content
 */
function wpclink_licensble_linked_images_start($html,$post_id = 0){
	
	// Enable error catch
	//libxml_use_internal_errors(TRUE);
	
	$html = '<meta http-equiv="Content-Type" content="text/html; charset=UTF-8" />'.$html;
	
	$doc = new DOMDocument('1.0', 'UTF-8');
	$doc->substituteEntities = TRUE;
    // If faild to load HTML
	if(@$doc->loadHTML($html) === false){
		return $html;
	}
	
	
	
	// Catch LibXML errors
	//$errors = libxml_get_errors();
	
		
    $images= $doc->getElementsByTagName('img');
    foreach ($images as $image) {
	
		if($image->hasAttribute('src')){
			
			// Source Attribute
			$src_attr = $image->getAttribute('src');
			
			// Remove Query
			$src_attr = strtok((string)$src_attr, '?');
			
			//var_dump($src_attr);
			
			
			
			// is Attachment
			if($attached_image_data = get_post_meta($post_id,'wpclink_referent_media_attributes',true)){
				
				
				$clink_attr = $attached_image_data[$src_attr];
				
				if(isset($clink_attr['creation_ID'])){
					if(!empty($clink_attr['creation_ID'])){
						
						if($image->hasAttribute('data-creation-id')){
							$image->setAttribute('src', $clink_attr['creation_ID']);
						}else{
							
							$doc_attr = $doc->createAttribute('data-creation-id');
							$doc_attr->value = wpclink_strip_prefix_clink_ID($clink_attr['creation_ID']);
						
							// Append it to the document itself 
							$image->appendChild($doc_attr); 
						}
						
						
						if(!empty($clink_attr['creation_ID_url'])){
							
							
							if($image->hasAttribute('data-creation-id-url')){
								$image->setAttribute('src', $clink_attr['creation_ID_url']);
							}else{
								$doc_attr = $doc->createAttribute('data-creation-id-url');
								$doc_attr->value = $clink_attr['creation_ID_url'];
								// Append it to the document itself 
								$image->appendChild($doc_attr); 
							}
							
						}
						


						
						if($image->hasAttribute('data-referent-post-url')){
							$image->setAttribute('data-referent-post-url', $clink_attr['orgin_url']);
						}else{
							$doc_attr = $doc->createAttribute('data-referent-post-url');
							$doc_attr->value = $clink_attr['orgin_url'];
							// Append it to the document itself 
							$image->appendChild($doc_attr); 
						}
				
				
						
					if(isset($clink_attr['reuse'])){
							if(!empty($clink_attr['reuse'])){
								
								$image_linked_array[$src_attr]['reuse'] = $clink_attr['reuse'];
								
								if($image->hasAttribute('data-reuse')){
									$image->setAttribute('data-reuse', $clink_attr['reuse']);
								}else{
									$doc_attr = $doc->createAttribute('data-reuse');
									$doc_attr->value = $clink_attr['reuse'];
									// Append it to the document itself 
									$image->appendChild($doc_attr); 
								}
								
								if($image->hasAttribute('data-reuse-url')){
									$image->setAttribute('data-reuse-url', $clink_attr['reuse_url']);
								}else{
									$doc_attr = $doc->createAttribute('data-reuse-url');
									$doc_attr->value = $clink_attr['reuse_url'];
									// Append it to the document itself 
									$image->appendChild($doc_attr); 
								}
							}
						}
						
						
						
						if(isset($clink_attr['custom-license'])){
							if(!empty($clink_attr['custom-license'])){
								
								$image_linked_array[$src_attr]['custom-license'] = $clink_attr['custom-license'];
								
								if($image->hasAttribute('data-custom-license')){
									$image->setAttribute('data-custom-license', $clink_attr['reuse']);
								}else{
									$doc_attr = $doc->createAttribute('data-custom-license');
									$doc_attr->value = $clink_attr['custom-license'];
									// Append it to the document itself 
									$image->appendChild($doc_attr); 
								}
								
							}
						}
						
							if(isset($clink_attr['button-label'])){
							if(!empty($clink_attr['button-label'])){
								
								$image_linked_array[$src_attr]['button-label'] = $clink_attr['button-label'];
								
								if($image->hasAttribute('data-button-label')){
									$image->setAttribute('data-button-label', $clink_attr['button-label']);
								}else{
									$doc_attr = $doc->createAttribute('data-button-label');
									$doc_attr->value = $clink_attr['button-label'];
									// Append it to the document itself 
									$image->appendChild($doc_attr); 
								}
								
							}
						}
						
						
						if(isset($clink_attr['use_mouse_over'])){
							if(!empty($clink_attr['use_mouse_over'])){			
								if($image->hasAttribute('data-use-mouse-over')){
									$image->setAttribute('data-use-mouse-over', $clink_attr['use_mouse_over']);
								}else{
									$doc_attr = $doc->createAttribute('data-use-mouse-over');
									$doc_attr->value = $clink_attr['use_mouse_over'];
									// Append it to the document itself 
									$image->appendChild($doc_attr); 
								}
							}
						}
					
						
					}
				}
				
	if(wpclink_is_amp_active()){	
	if(isset($clink_attr['creation_ID'])){
			if(!empty($clink_attr['creation_ID'])){

		//Create new wrapper div
		$new_div = $doc->createElement('div');
		$new_div->setAttribute('class','clink-imagebox');

		//Clone our created div
		$new_div_clone = $new_div->cloneNode();

		$uniq_id = uniqid();
		$image->parentNode->replaceChild($new_div_clone,$image);

		//Append this image to wrapper div
		$new_div_clone->appendChild($image);

		/* Image Panel */
		$image_panel = $doc->createElement("div");
		$image_panel->setAttribute('class','clink-imagepanel');
		$added_image_panel = $new_div_clone->appendChild($image_panel);

		/* Reuse URL */
		if(isset($clink_attr['reuse'])){
			if(!empty($clink_attr['reuse'])){

				$reuse_url = $clink_attr['reuse_url'];

				if($clink_attr['button-label'] == 'na' || empty($clink_attr['button-label']) ){
					$button_label = 'Get a License';
				}else{
					$button_label = $clink_attr['button-label'];
				}

				$get_license = $doc->createElement("a",$button_label);
				$get_license->setAttribute('class','cl-resuse');
				$get_license->setAttribute('target','_blank');
				$get_license->setAttribute('href',urldecode($reuse_url));
				$added_image_panel->appendChild($get_license);	

			}
		}


		// Clink more links
		$clink_more_links = $doc->createElement("div");
		$clink_more_links->setAttribute('class','clink-more-links');
		$added_more_links = $added_image_panel->appendChild($clink_more_links);

		// Span
		$span = $doc->createElement("span");	
		$span_attr = $doc->createAttribute('on');
		$span_attr->value = 'tap:clbtn-'.$uniq_id.'.show';
		$span_done = $span->appendChild($span_attr);

		$adde_span = $added_more_links->appendChild($span);	

		// Clink ul links
		$clink_ul_links = $doc->createElement("div");
		$clink_ul_links->setAttribute('class','clink-ul-links cl-amp-btn');
		$clink_ul_links->setAttribute('id','clbtn-'.$uniq_id);

		// hidden
		$attr_hidden = $doc->createAttribute('hidden');
		$clink_ul_links_done = $clink_ul_links->appendChild($attr_hidden);
		$clink_ul_links_added = $added_more_links->appendChild($clink_ul_links);


		$li_creation = $doc->createElement("li");
		$li_a = $doc->createElement("a",'Provenance and rights');
		$li_a->setAttribute('class','cl-clinkid');
		$li_a->setAttribute('target','_blank');
		$li_a->setAttribute('href',$clink_attr['creation_ID_url']);

		$li_creation_added = $clink_ul_links_added->appendChild($li_creation);
		$li_creation_done = $li_creation_added->appendChild($li_a);


		if(isset($clink_attr['orgin_url']) and !empty($clink_attr['orgin_url'])){

			// Li Referent
			$li_referent = $doc->createElement("li");
			$li_referent->setAttribute('class','archive_link');

			// A Referent
			$li_referent_a = $doc->createElement("a",'Referent (Origin)');
			$li_referent_a->setAttribute('target','_blank');
			$li_referent_a->setAttribute('href',urldecode($clink_attr['orgin_url']));

			// SVG
			$svg_referent = $doc->createElement("svg");
			$svg_referent->setAttribute('xmlns','http://www.w3.org/2000/svg');	
			$svg_referent->setAttribute('viewBox','0 0 24 24');	
			$svg_referent->setAttribute('class','ico_link');	


			$li_referent_a_added = $li_referent_a->appendChild($svg_referent);	


			$li_added = $clink_ul_links_added->appendChild($li_referent);
			$a_added = $li_added->appendChild($li_referent_a);
			$svg_added = $a_added->appendChild($svg_referent);



			$svg_referent_path = $doc->createElement("path");
			$svg_referent_path->setAttribute('d','M15.6 7.2H14v1.5h1.6c2 0 3.7 1.7 3.7 3.7s-1.7 3.7-3.7 3.7H14v1.5h1.6c2.8 0 5.2-2.3 5.2-5.2 0-2.9-2.3-5.2-5.2-5.2zM4.7 12.4c0-2 1.7-3.7 3.7-3.7H10V7.2H8.4c-2.9 0-5.2 2.3-5.2 5.2 0 2.9 2.3 5.2 5.2 5.2H10v-1.5H8.4c-2 0-3.7-1.7-3.7-3.7zm4.6.9h5.3v-1.5H9.3v1.5z');

			$svg_path_added = $svg_added->appendChild($svg_referent_path);



			}



			}
	}
				
			}
			
			
		}
		
		}
    
	
    
	
	}
	
	return $doc->saveHTML();
	
}
add_filter( 'the_content', 'wpclink_licenable_images' );
/**
 * CLink Licensable DOM HTML After
 * 
 * @param string $html Content
 * 
 * @return string Content
 */
function wpclink_licenable_images($html){
	
	global $post;
	
	if ( ! is_admin() ) {
		
	if(!isset($post->ID)) return $html;
	
	// Is content is linked?
	$linked_content = get_post_meta( $post->ID, 'wpclink_referent_post_link', true );
	if ( !empty( $linked_content ) ) {
		return $html;
	} 
		return wpclink_licensble_images_start($html,$post->ID);

	}else{
		return $html;	
	}
	
}
add_filter( 'the_content', 'wpclink_licenable_linked_images' );
/**
 * CLink Linked Licensable DOM HTML After
 * 
 * @param string $html Content
 * 
 * @return string Content
 */
function wpclink_licenable_linked_images($html){
	
	global $post;
	
	if ( ! is_admin() ) {
		
	if(!isset($post->ID)) return $html;
		
	// Is content is linked?
	$linked_content = get_post_meta( $post->ID, 'wpclink_referent_post_link', true );
	if ( !empty( $linked_content ) ) {
		if ( ! is_admin() ) {
			return wpclink_licensble_linked_images_start($html,$post->ID);
		}else{
			return $html;
		}
		
	}else{
		return $html;
	}
		
	}else{
		return $html;
	}
	
}

/**
 * CLink Check License When Post Update
 * 
 * @param string $html Content
 * 
 * @return string Content
 */
function wpclink_check_license_from_post_content($html,$post_id = 0){
	
	// Enable error catch
	//libxml_use_internal_errors(TRUE);
	
	// Referent Post
	if($linked_post = get_post_meta($post_id,'wpclink_referent_post_link',true)){
		if(!empty($linked_post)){
			return false;
		}
	}
	
	// Has License
	$all_referent_posts = wpclink_get_option('referent_posts');
	$all_referent_pages = wpclink_get_option('referent_pages');
	
	if(in_array($post_id,$all_referent_posts) || in_array($post_id,$all_referent_pages) ){
		
	}else{
		return false;
	}
	
	// Registered
	if($contentID = get_post_meta( $post_id, 'wpclink_creation_ID', true )){
		
	}else{
		return false;
	}
	
	// UTF-8 Doc Document
	$html = '<meta http-equiv="Content-Type" content="text/html; charset=UTF-8" />'.$html;
	
	$doc = new DOMDocument('1.0', 'UTF-8');
	$doc->substituteEntities = TRUE;
    // If faild to load HTML
	if(@$doc->loadHTML($html) === false){
		return false;
	}
	
	// Catch LibXML errors
	//$errors = libxml_get_errors();
	
	$image_linked_array = array();
		
    $images= $doc->getElementsByTagName('img');
    foreach ($images as $image) {
	
		if($image->hasAttribute('src')){
			
			// Source Attribute
			$src_attr = $image->getAttribute('src');
			
			
			
			// Remove Query
			//$src_attr = strtok((string)$src_attr, '?');
			
			//var_dump($src_attr);
			
			// Attachment ID
			$attach_id = wpclink_find_image_id_by_url((string)$src_attr);
			
			// Remove Query
			$src_attr = strtok((string)$src_attr, '?');
			
			
			//var_dump($attach_id);
			
			// is Attachment
			if($attach_id > 0){
				
				if($linked_media = get_post_meta($attach_id,'wpclink_referent_post_link',true)){
					if(!empty($linked_media)){
						return $attach_id;
					}
				}
				
			}
			
			
		}

	}
	
	return false;
}
